from os import path as op

import pytest

import pyslk as slk
import pyslk.transfer.retrieve

from . import requires_slk, scratch

# once there is a test system ...
test_file = "test.txt"
arch_path = "/arch/ch0636/pyslk"


@pytest.fixture
def resource():
    with open(test_file, "w") as f:
        f.write("test content for pyslk")
    return test_file


@requires_slk
def test_with_slk(resource):
    # run slk commands once we have a test system
    out = slk.slk_archive(resource, arch_path)
    assert out == "Non-recursive Archive completed"

    retr = pyslk.transfer.retrieve.retrieve(op.join(arch_path, test_file))
    assert retr == ""


@requires_slk
def test_list():
    out = slk.list("/")
    assert "/arch" in out.filename.to_list()


@requires_slk
def test_retrieve():
    path = "/test/test3/ingest_01_1"
    out = pyslk.transfer.retrieve.retrieve(path, scratch)
    assert out == ""

    # retrieve
    path = ["/test/test3/ingest_01_1", "/test/test3/ingest_01_10"]
    out = pyslk.transfer.retrieve.retrieve(path, scratch, group=False)
    for o in out:
        assert o == ""

    # grouped retrieve
    # path = ["/test/test3/ingest_01_1", "/test/test3/ingest_01_10"]
    # out = slk.retrieve(path, scratch, group=True)
    # for o in out:
    #    assert o == ''
